@@ -1,16 +1,11 @@
 package Bryar;
-
 use Bryar::Config;
-use Time::Local;
 use Bryar::Comment;
-use Calendar::Simple;
-use DateTime;
-
 use 5.006;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = '2.8_02';
+our $VERSION = '2.1';
 
 =head1 NAME
 
@@ -49,9 +44,9 @@ For instance, my F<bryar.cgi> looks like this:
     #!/usr/bin/perl
     use Bryar;
     Bryar->go(
-	 name => "Themes, Dreams and Crazy Schemes",
-	 description => "Simon Cozens' weblog",
-	 baseurl => "http://blog.simon-cozens.org/bryar.cgi"
+         name => "Themes, Dreams and Crazy Schemes",
+         description => "Simon Cozens' weblog",
+         baseurl => "http://blog.simon-cozens.org/bryar.cgi"
     );
 
 You can get away without any configuration options, but it's probably
@@ -122,17 +117,6 @@ And combine subblogging with RSS:
 
     http://your.blog.com/bryar.cgi/otherblog/xml
 
-These are actually blosxom backwardly-compatible versions of the Bryar:
-
-    http://your.blog.com/bryar.cgi?format=xml
-
-There's also an Atom feed:
-
-    http://your.blog.com/bryar.cgi?format=atom
-
-And you can write your own formats; see the renderer class documentation for
-how.
-
 Each blog post will have a unique ID; you can get to an individual post
 by specifying its ID:
 
@@ -160,12 +144,11 @@ you're programming your blog to do clever stuff. Use C<go> instead.
 
 =cut
 
+
 sub new {
     my $class = shift;
-	my %args = (configclass => 'Bryar::Config', @_);
-	eval "require $args{configclass}" or die $@;
     bless {
-	config => $args{configclass}->new(@_)
+        config => Bryar::Config->new(@_)
     }, $class;
 }
 
@@ -182,97 +165,45 @@ interested in setting, see C<Bryar::Config>.
 sub go {
     my $self = shift;
     if (not ref $self) {
-	# We need to acquire a Bryar object.
-	my %args = @_;
+        # We need to acquire a Bryar object.
+        my %args = @_;
 
-	# If we're running under mod_perl, then we want to check to see
-	# if a datadir or config file has been specified.
-	if (exists $ENV{GATEWAY_INTERFACE} and 
-	    $ENV{'GATEWAY_INTERFACE'} =~ /^CGI-Perl\//) {
-	    require Apache;
-	    my $r = Apache->request;
-	    my $x;
-	    $args{datadir} = $x if $x = $r->dir_config("BryarDatadir");
-	    $args{config}  = $x if $x = $r->dir_config("BryarConfig");
-	}
-	$self = Bryar->new(%args);
+        # If we're running under mod_perl, then we want to check to see
+        # if a datadir or config file has been specified.
+        if (exists $ENV{GATEWAY_INTERFACE} and 
+            $ENV{'GATEWAY_INTERFACE'} =~ /^CGI-Perl\//) {
+            require Apache;
+            my $r = Apache->request;
+            my $x;
+            $args{datadir} = $x if $x = $r->dir_config("BryarDatadir");
+            $args{config}  = $x if $x = $r->dir_config("BryarConfig");
+        }
+        $self = Bryar->new(%args);
     }
-    my $frontend = $self->config->frontend();
-    $frontend->init($self->config) if $frontend->can("init");
-    
-	$self->_doit;
+    my $frontend = $self->{config}->frontend();
+    $frontend->init($self) if $frontend->can("init");
+
+    $self->_doit;
 }
 
 sub _doit {
     my $self = shift;
-    my %args = $self->config->frontend()->parse_args($self->config, @_);
-	$self->{arguments} = \%args;
+    my %args = $self->{config}->frontend()->parse_args($self);
+    my @documents = $self->{config}->collector()->collect($self, %args);
 
-    my @documents = $self->config->collector()->collect($self->config, %args);
+    # XML or HTML?
+    my $out;
+    my $ct = "text/html";
+    if (exists $args{xml}) {
+        $out = $self->{config}->renderer->generate_rss($self, @documents);
+        $ct = "text/xml";
+    } else {
+        $out = $self->{config}->renderer->generate_html($self, @documents);
+    }
 
-    $args{format} ||= "html";
-
-	use Data::Dumper;
-	print STDERR Dumper($self->arguments), "\n";
-
-    $self->config->frontend()->output(
-		$self->config->renderer->generate(
-					$self->{arguments}{format},
-					$self,
-					@documents
-				)
-    );
-}
-
-=head2 posts_calendar
-
-TODO:  Move this out to something that is more flexible.
-
-Return a data structure containing the days and weeks of a given month and
-year with blog posts attached. See the C<calendar> template for an example.
-
-=cut
-
-sub posts_calendar {
-	my ($self, $month, $year) = @_;
-
-    my $today = DateTime->today( time_zone => $self->config->{time_zone} );
-
-	$month ||= $today->month(); 
-	$year  ||= $today->year(); 
-
-	my $this_month = DateTime->new( month => $month, year => $year,  time_zone => $self->config->{time_zone} );
-
-	my @documents = $self->config->collector->collect(
-		$self->config,
-		since => $this_month->epoch()
-	);
-
-	# make an hash with keys the days with a post
-	my %posts = map { DateTime->from_epoch( epoch => $_->{epoch},  time_zone => $self->config->{time_zone} )->day() => $_->{id} } @documents;
-use Data::Dumper;
-print STDERR Dumper(\%posts);
-
-	my @m = calendar($month, $year);
-	my @month;
-	foreach my $week (@m) {
-		my @weekdays;
-		foreach my $day (@$week) {
-			my $d = { day => $day };
-			if ($day and exists $posts{$day}) {
-				$d->{idlink} = $posts{$day};
-				$d->{link} = "$year/" . $this_month->month_abbr() . "/$day";
-			}
-			push(@weekdays, $d);
-		}
-
-		# mark the first day of the week, if it exists
-		$weekdays[0]{sunday} = 1 if defined $weekdays[0]{day};
-
-		push(@month, \@weekdays);
-	}
-
-	return { year => $year, month => $month, monthname => $this_month->month_name(), calendar => \@month };
+    # I fully realise that this is nowhere near as generic as it needs
+    # to be, but I'm working on the YAGNI principle for the time being.
+    $self->{config}->frontend()->output($ct, $out);
 }
 
 =head2 config
@@ -290,14 +221,9 @@ sub arguments {return $_[0]->{arguments} }
 This module is free software, and may be distributed under the same
 terms as Perl itself.
 
-=head1 THANKS
-
-Steve Peters provided Atom support. Marco d'Itri added ETag and
-Cache-Control support, as well as the calendar.
-
 =head1 AUTHOR
 
-Copyright (C) 2003, Simon Cozens C<simon@cpan.org>
+Copyright (C) 2003, Simon Cozens C<simon@kasei.com>
 
 =cut
 
