@@ -6,7 +6,6 @@ use Carp;
 our $VERSION = '1.1';
 use Time::Piece;
 use Time::Local;
-use Digest::MD5 qw(md5_hex);
 
 =head1 NAME
 
@@ -20,7 +19,6 @@ Bryar::Frontend::Base - Base class for frontend classes
     sub obtain_args {...}
     sub send_data {...}
     sub send_header {...}
-    sub get_header {...}
 
 =head1 DESCRIPTION
 
@@ -52,10 +50,6 @@ Write stuff to the browser. This will only be called once.
 
 Write stuff to the browser, first.
 
-=head2 get_header
-
-Read a HTTP header.
-
 =cut
 
 sub obtain_url { croak "Don't use Bryar::FrontEnd::Base directly"; }
@@ -63,28 +57,26 @@ sub obtain_params { croak "Abstract base class. ABSTRACT BASE CLASS."; }
 
 sub parse_args {
     my $self = shift;
-    my $config = shift;
+    my $bryar = shift;
     my %params = $self->obtain_params();
-    my %args = $self->parse_path($config);
+    my %args = $self->parse_path($bryar);
     if (my $search = $params{search}) {
         $args{content} = $search if $search =~ /\S{3,}/; # Avoid trivials.
     }
-    for (qw(comments format)) {
-		$args{$_} = $params{$_} if exists $params{$_};
-    }
-    $self->process_new_comment($config, %params) if $params{newcomment};
+    $args{comments} = $params{comments} if $params{comments};
+    $self->process_new_comment($bryar, %params) if $params{newcomment};
     return %args;
 }
 
 sub parse_path {
-    my ($self, $config) = @_;
+    my ($self, $bryar) = @_;
     my $pi = $self->obtain_path_info();
     my @pi = split m{/}, $pi;
     shift @pi while @pi and not$pi[0];
     #...
 
     my %args;
-    if (defined $pi[-1] and $pi[-1] eq "xml")     { $args{format} = "xml"; pop @pi; }
+    if (defined $pi[-1] and $pi[-1] eq "xml")     { $args{xml} = 1; pop @pi; }
     if (defined $pi[-1] and $pi[-1] =~ /id_(.*)/) { $args{id} = $1; pop @pi; }
     if (defined $pi[0] and $pi[0] =~ /^([a-zA-Z]\w*)/) { # We have a subblog
         $args{subblog} = $1;
@@ -97,18 +89,18 @@ sub parse_path {
             $args{since} = $from;
         }
     } else {
-        $args{limit}   = $config->{recent} if $args{subblog};
+        $args{limit}   = $bryar->config->recent if $args{subblog};
     }
 
     return %args;
 }
 
 sub process_new_comment {
-    my ($self, $config, %params) = @_;
-    my ($doc) = $config->source->search($config, id => $params{id});
+    my ($self, $bryar, %params) = @_;
+    my ($doc) = $bryar->config->source->search($bryar, id => $params{id});
     $self->report_error("Couldn't find Doc $params{id}") unless $doc;
-    $config->source->add_comment(
-        $config,
+    $bryar->config->source->add_comment(
+        $bryar,
         document => $doc,
         author => $params{author},
         url => $params{url},
@@ -142,30 +134,14 @@ sub _make_from_til {
 
     $self->output
 
-Output the entire blog data to the browser
+This is a useful method, and should have a useful description.
 
 =cut
 
 sub output {
     my ($self, $ct, $data) = @_;
     $self->send_header("Content-type", $ct);
-    $self->send_header('Cache-Control', 'max-age=180');
-    if ($self->_etag($data)) {
-        $self->send_header('Status', '304 Not Modified');
-        $self->send_header('Content-Length', 0);
-        $self->send_data('');
-    } else {
-        $self->send_header('Content-Length', length($data));
-        $self->send_data($data);
-    }
-}
-
-sub _etag {
-    my ($self, $data) = @_;
-    my $req_tag = $self->get_header("If-None-Match") || '';
-    my $etag = '"'.md5_hex($data).'"';
-    $self->send_header('ETag', $etag);
-    return $etag eq $req_tag;
+    $self->send_data($data);
 }
 
 =head2 report_error
@@ -185,10 +161,10 @@ sub report_error {
 }
 
 sub init {
-    my ($self, $config) = @_;
+    my ($self, $bryar) = @_;
     my $url = $self->obtain_url();
-    if (!$config->baseurl) {
-        $config->baseurl($url) if $url =~ s/((bryar|blosxom).cgi).*/$1/;
+    if (!$bryar->config->baseurl) {
+        $bryar->config->baseurl($url) if $url =~ s/((bryar|blosxom).cgi).*/$1/;
     }
 }
 =head1 LICENSE
@@ -196,12 +172,16 @@ sub init {
 This module is free software, and may be distributed under the same
 terms as Perl itself.
 
+
 =head1 AUTHOR
 
 Copyright (C) 2003, Simon Cozens C<simon@kasei.com>
 
+
 =head1 SEE ALSO
 
+
+
 =cut
 
 1;
